# PyHutool
<p align="center">
	<a href="https://pyhutool.readthedocs.org"><img src="https://www.xujiantao.com/images/pyhutool-logo.png" width="45%"></a>
</p>
<p align="center">
	<strong>🍬A set of tools that keep Python sweet.</strong>
</p>
<p align="center">
	👉 <a href="https://pyhutool.readthedocs.org">https://pyhutool.readthedocs.org</a> 👈
</p>

[![Documentation Status](https://readthedocs.org/projects/pyhutool/badge/?version=latest)](https://pyhutool.readthedocs.io/en/latest/?badge=latest)
[![GitHub license](https://img.shields.io/github/license/KAY53N/PyHutool)](https://github.com/KAY53N/PyHutool/blob/main/LICENSE)
[![GitHub issues](https://img.shields.io/github/issues/KAY53N/PyHutool)](https://github.com/KAY53N/PyHutool/issues)
[![GitHub stars](https://img.shields.io/github/stars/KAY53N/PyHutool)](https://github.com/KAY53N/PyHutool/stargazers)

PyHutool draws lessons from Java's Hutool to reduce the learning cost of related APIs and improve work efficiency

## 📝文档 
[📘中文文档](https://pyhutool.readthedocs.io/zh_CN/latest/index.html)
Full documentation available at https://pyhutool.readthedocs.org


## 🛠️包含组件
| 模块                | 介绍                               |
| -------------------|----------------------------------|
| pyhutool.core        | 核心，包括文件处理、数据转换、日期、各种Util等        |
| pyhutool.gui         | 自动化库，包含按键、鼠标、截图的操作等              |
| pyhutool.system         | 获取系统相关信息，如显示器数量，当前窗口标题，系统运行的应用信息 |
| pyhutool.crypto         | 加密解密模块，提供对称、非对称和摘要算法封装           |
| pyhutool.cryptocurrency | 加密货币相关类库封装       |

